# (c) 2018
#     MPIB <https://www.mpib-berlin.mpg.de/>,
#     MPI-CBS <https://www.cbs.mpg.de/>,
#     MPIP <http://www.psych.mpg.de/>
#
# This file is part of Castellum.
#
# Castellum is free software; you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Castellum is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public
# License along with Castellum. If not, see
# <http://www.gnu.org/licenses/>.


from django.shortcuts import get_object_or_404
from django.urls import reverse

from castellum.contacts.models import Contact
from castellum.contacts.views import ContactUpdateView as _ContactUpdateView
from castellum.pseudonyms.helpers import resolve_pseudonym

from ..models import ParticipationRequest
from .mixins import PublishedStudyMixin


class ContactUpdateView(PublishedStudyMixin, _ContactUpdateView):
    def get_object(self):
        participation_request = get_object_or_404(
            ParticipationRequest, study=self.study, pseudonym=self.kwargs['slug'])

        contact_pseudonym = resolve_pseudonym(
            self.study.domain,
            participation_request.pseudonym,
            Contact.domain)
        contact = get_object_or_404(Contact, pseudonym=contact_pseudonym)

        return contact

    def get_success_url(self):
        return reverse('recruitment:contact',
                       args=[self.kwargs['study_pk'], self.kwargs['slug'], self.kwargs['path']])

    def get_cancel_url(self):
        return self.get_success_url()
